@@ -27,8 +27,9 @@ from slack_sdk import WebhookClient
 from slack_sdk.webhook.async_client import AsyncWebhookClient
 
 from airflow.exceptions import AirflowException, AirflowNotFoundException
-from airflow.providers.slack.utils import ConnectionExtraConfig, get_async_connection
-from airflow.providers.slack.version_compat import BaseHook
+from airflow.providers.common.compat.connection import get_async_connection
+from airflow.providers.common.compat.sdk import BaseHook
+from airflow.providers.slack.utils import ConnectionExtraConfig
 
 if TYPE_CHECKING:
     from slack_sdk.http_retry import RetryHandler
